@@ -1,5 +1,5 @@
 /*
- * Copyright (c) Facebook, Inc. and its affiliates.
+ * Copyright (c) Meta Platforms, Inc. and affiliates.
  * All rights reserved.
  *
  * This source code is licensed under the BSD-style license found in the
@@ -10,6 +10,7 @@
 
 #include <stdint.h>
 #include <string>
+#include <vector>
 
 namespace proxygen {
 
@@ -24,20 +25,15 @@ enum ErrorCode : uint16_t {
   HTTP_FRAME_UNEXPECTED = 0x105,
   HTTP_FRAME_ERROR = 0x106,
   HTTP_EXCESSIVE_LOAD = 0x107,
-  HTTP_ID_ERROR = 0x108, // TODO: needs to audit the lack of use of this error.
+  HTTP_ID_ERROR = 0x108,
   HTTP_SETTINGS_ERROR = 0x109,
   HTTP_MISSING_SETTINGS = 0x10A,
   HTTP_REQUEST_REJECTED = 0x10B,
   HTTP_REQUEST_CANCELLED = 0x10C,
   HTTP_INCOMPLETE_REQUEST = 0x10D,
+  HTTP_MESSAGE_ERROR = 0x10E,
   HTTP_CONNECT_ERROR = 0x10F,
   HTTP_VERSION_FALLBACK = 0x110,
-  // TODO: Homemade and legacy error code that should be audited:
-  HTTP_PUSH_REFUSED = 0x02,
-  HTTP_PUSH_ALREADY_IN_CACHE = 0x04,
-  HTTP_WRONG_STREAM = 0x0A,
-  HTTP_UNKNOWN_STREAM_TYPE = 0x0D,
-  HTTP_WRONG_STREAM_COUNT = 0x0E,
   // QPACK 0x200, all from draft
   HTTP_QPACK_DECOMPRESSION_FAILED = 0x200,
   HTTP_QPACK_ENCODER_STREAM_ERROR = 0x201,
@@ -47,6 +43,12 @@ enum ErrorCode : uint16_t {
   GIVEUP_ZERO_RTT = 0xF2
 };
 }
-std::string toString(HTTP3::ErrorCode code);
+inline bool isQPACKError(HTTP3::ErrorCode err) {
+  return err == HTTP3::ErrorCode::HTTP_QPACK_DECOMPRESSION_FAILED ||
+         err == HTTP3::ErrorCode::HTTP_QPACK_ENCODER_STREAM_ERROR ||
+         err == HTTP3::ErrorCode::HTTP_QPACK_DECODER_STREAM_ERROR;
+}
 
+std::string toString(HTTP3::ErrorCode code);
+std::vector<HTTP3::ErrorCode> getAllHTTP3ErrorCodes();
 } // namespace proxygen
