@@ -56,6 +56,9 @@ enum class FrameType : uint64_t {
   // the RFC compliant frame types.
   FB_PRIORITY_UPDATE = 0xF700,
   FB_PUSH_PRIORITY_UPDATE = 0xF701,
+
+  // THIS IS NOT A FRAME TYPE, but we treat it like one
+  WEBTRANSPORT_BIDI = 0x41,
 };
 
 std::ostream& operator<<(std::ostream& os, FrameType type);
@@ -69,7 +72,12 @@ enum class SettingId : uint64_t {
   HEADER_TABLE_SIZE = 0x01,
   MAX_HEADER_LIST_SIZE = 0x06,
   QPACK_BLOCKED_STREAMS = 0x07,
-  H3_DATAGRAM = 0x276,
+  ENABLE_CONNECT_PROTOCOL = 0x08,
+  H3_DATAGRAM = 0x276, // DRAFT_0
+  H3_DATAGRAM_DRAFT_8 = 0xffd277,
+  H3_DATAGRAM_RFC = 0x33,
+  ENABLE_WEBTRANSPORT = 0x2b603742,
+  WEBTRANSPORT_MAX_SESSIONS = 0x2b603743,
 };
 
 using SettingValue = uint64_t;
