@@ -110,7 +110,8 @@ HTTP1xCodec::HTTP1xCodec(TransportDirection direction,
       ingressUpgradeComplete_(false),
       egressUpgrade_(false),
       nativeUpgrade_(false),
-      headersComplete_(false) {
+      headersComplete_(false),
+      releaseEgressAfterRequest_(false) {
   switch (direction) {
     case TransportDirection::DOWNSTREAM:
       http_parser_init(&parser_, HTTP_REQUEST);
@@ -231,6 +232,7 @@ size_t HTTP1xCodec::onIngressImpl(const IOBuf& buf) {
     // the headers we need to keep accounting of it for total header size
     if (!headersComplete_) {
       headerSize_.uncompressed += bytesParsed;
+      headerSize_.compressed += bytesParsed;
     }
     parserActive_ = false;
     parserError_ = (HTTP_PARSER_ERRNO(&parser_) != HPE_OK) &&
@@ -687,7 +689,7 @@ void HTTP1xCodec::generateHeader(
   }
 
   if (size) {
-    size->compressed = 0;
+    size->compressed = len;
     size->uncompressed = len;
   }
 }
