@@ -1,5 +1,5 @@
 /*
- * Copyright (c) Facebook, Inc. and its affiliates.
+ * Copyright (c) Meta Platforms, Inc. and affiliates.
  * All rights reserved.
  *
  * This source code is licensed under the BSD-style license found in the
@@ -31,7 +31,20 @@ class HTTPCodecFactory {
                                               bool isTLS) = 0;
 
   static std::unique_ptr<HTTPCodec> getCodec(CodecProtocol protocol,
-                                             TransportDirection direction);
+                                             TransportDirection direction,
+                                             bool strictValidation = false);
+
+  void setStrictValidationFn(std::function<bool()> useStrictValidationFn) {
+    useStrictValidationFn_ = useStrictValidationFn;
+  }
+
+ protected:
+  bool useStrictValidation() {
+    return useStrictValidationFn_();
+  }
+
+  // Default to false for now to match existing behavior
+  std::function<bool()> useStrictValidationFn_{[] { return false; }};
 };
 
 } // namespace proxygen
