@@ -29,6 +29,7 @@
 #include <proxygen/lib/http/session/HTTPSessionBase.h>
 #include <proxygen/lib/http/session/HTTPSessionController.h>
 #include <proxygen/lib/http/session/HTTPTransaction.h>
+#include <proxygen/lib/http/session/QuicProtocolInfo.h>
 #include <proxygen/lib/http/session/ServerPushLifecycle.h>
 #include <proxygen/lib/utils/ConditionalGate.h>
 #include <quic/api/QuicSocket.h>
@@ -71,62 +72,6 @@ constexpr uint8_t kMaxStreamsWithBufferedDatagrams = 10;
 // Maximum number of priority updates received when stream is not available
 constexpr uint8_t kMaxBufferedPriorityUpdates = 10;
 
-/**
- * Session-level protocol info.
- */
-struct QuicProtocolInfo : public wangle::ProtocolInfo {
-  virtual ~QuicProtocolInfo() override = default;
-
-  folly::Optional<quic::ConnectionId> clientChosenDestConnectionId;
-  folly::Optional<quic::ConnectionId> clientConnectionId;
-  folly::Optional<quic::ConnectionId> serverConnectionId;
-  folly::Optional<quic::TransportSettings> transportSettings;
-
-  uint32_t ptoCount{0};
-  uint32_t totalPTOCount{0};
-  uint64_t totalTransportBytesSent{0};
-  uint64_t totalTransportBytesRecvd{0};
-  bool usedZeroRtt{false};
-};
-
-/**
- *  Stream level protocol info. Contains all data from
- *  the sessinon info, plus stream-specific information.
- *  This structure is owned by each individual stream,
- *  and is updated when requested.
- *  If instance of HQ Transport Stream outlives the corresponding QUIC socket,
- *  has been destroyed, this structure will contain the last snapshot
- *  of the data received from the QUIC socket.
- *
- * Usage:
- *   TransportInfo tinfo;
- *   txn.getCurrentTransportInfo(&tinfo); // txn is the HTTP transaction object
- *   auto streamInfo = dynamic_cast<QuicStreamProtocolInfo>(tinfo.protocolInfo);
- *   if (streamInfo) {
- *      // stream level AND connection level info is available
- *   };
- *   auto connectionInfo = dynamic_cast<QuicProtocolInfo>(tinfo.protocolInfo);
- *   if (connectionInfo) {
- *     // ONLY connection level info is available. No stream level info.
- *   }
- *
- */
-struct QuicStreamProtocolInfo : public QuicProtocolInfo {
-
-  // Slicing assignment operator to initialize the per-stream protocol info
-  // with the values of the per-session protocol info.
-  QuicStreamProtocolInfo& operator=(const QuicProtocolInfo& other) {
-    if (this != &other) {
-      *(static_cast<QuicProtocolInfo*>(this)) = other;
-    }
-    return *this;
-  }
-
-  quic::QuicSocket::StreamTransportInfo streamTransportInfo;
-  // NOTE: when the control stream latency stats will be reintroduced,
-  // collect it here.
-};
-
 class HQSession
     : public quic::QuicSocket::ConnectionSetupCallback
     , public quic::QuicSocket::ConnectionCallback
@@ -194,7 +139,7 @@ class HQSession
     }
   };
 
-  virtual ~HQSession();
+  ~HQSession() override;
 
   HTTPTransaction::Transport::Type getType() const noexcept override {
     return HTTPTransaction::Transport::Type::QUIC;
@@ -376,8 +321,14 @@ class HQSession
       });
     }
     auto datagramEnabled = egressSettings_.getSetting(SettingsId::_HQ_DATAGRAM);
+    auto datagramDraft8Enabled =
+        egressSettings_.getSetting(SettingsId::_HQ_DATAGRAM_DRAFT_8);
+    auto datagramRFCEnabled =
+        egressSettings_.getSetting(SettingsId::_HQ_DATAGRAM_RFC);
     // if enabling H3 datagrams check that the transport supports datagrams
-    if (datagramEnabled && datagramEnabled->value) {
+    if ((datagramEnabled && datagramEnabled->value) ||
+        (datagramDraft8Enabled && datagramDraft8Enabled->value) ||
+        (datagramRFCEnabled && datagramRFCEnabled->value)) {
       datagramEnabled_ = true;
     }
   }
@@ -482,6 +433,12 @@ class HQSession
     versionUtilsReady_.then([this, stats] { qpackCodec_.setStats(stats); });
   }
 
+  void setHeaderIndexingStrategy(const HeaderIndexingStrategy* indexingStrat) {
+    versionUtilsReady_.then([this, indexingStrat] {
+      qpackCodec_.setHeaderIndexingStrategy(indexingStrat);
+    });
+  }
+
   void enableDoubleGoawayDrain() override {
   }
 
@@ -518,11 +475,6 @@ class HQSession
     return sock_ && sock_->good() ? sock_->getPeerAddress() : peerAddr_;
   }
 
-  // Returns creation time point for logging of handshake duration
-  const std::chrono::steady_clock::time_point& getCreatedTime() const {
-    return createTime_;
-  }
-
   void enablePingProbes(std::chrono::seconds /*interval*/,
                         std::chrono::seconds /*timeout*/,
                         bool /*extendIntervalOnIngress*/,
@@ -713,7 +665,8 @@ class HQSession
         dropping_(false),
         inLoopCallback_(false),
         unidirectionalReadDispatcher_(*this, direction),
-        createTime_(std::chrono::steady_clock::now()) {
+        sessionObserverAccessor_(this),
+        sessionObserverContainer_(&sessionObserverAccessor_) {
     codec_.add<HTTPChecks>();
     // dummy, ingress, egress
     codecStack_.reserve(kMaxCodecStackDepth);
@@ -1930,14 +1883,42 @@ class HQSession
   folly::EvictingCacheMap<quic::StreamId, HTTPPriority> priorityUpdatesBuffer_{
       kMaxBufferedPriorityUpdates};
 
-  // Creation time (for handshake time tracking)
-  std::chrono::steady_clock::time_point createTime_;
-
   // Lookup maps for matching PushIds to StreamIds
   folly::F14FastMap<hq::PushId, quic::StreamId> pushIdToStreamId_;
   // Lookup maps for matching ingress push streams to push ids
   folly::F14FastMap<quic::StreamId, hq::PushId> streamIdToPushId_;
   std::string userAgent_;
+
+  /**
+   * Accessor implementation for HTTPSessionObserver.
+   */
+  class ObserverAccessor : public HTTPSessionObserverAccessor {
+   public:
+    explicit ObserverAccessor(HTTPSessionBase* sessionBasePtr)
+        : sessionBasePtr_(sessionBasePtr) {
+      (void)sessionBasePtr_; // silence unused variable warnings
+    }
+    ~ObserverAccessor() override = default;
+
+   private:
+    HTTPSessionBase* sessionBasePtr_{nullptr};
+  };
+
+  ObserverAccessor sessionObserverAccessor_;
+
+  // Container of observers for a HTTP session
+  //
+  // This member MUST be last in the list of members to ensure it is destroyed
+  // first, before any other members are destroyed. This ensures that observers
+  // can inspect any session state available through public methods
+  // when destruction of the session begins.
+  HTTPSessionObserverContainer sessionObserverContainer_;
+
+  HTTPSessionObserverContainer* getHTTPSessionObserverContainer()
+      const override {
+    return const_cast<HTTPSessionObserverContainer*>(
+        &sessionObserverContainer_);
+  }
 }; // HQSession
 
 std::ostream& operator<<(std::ostream& os, HQSession::DrainState drainState);
