@@ -19,6 +19,7 @@
 #include <proxygen/lib/http/session/test/HTTPSessionMocks.h>
 #include <proxygen/lib/http/session/test/HTTPTransactionMocks.h>
 #include <proxygen/lib/http/session/test/MockQuicSocketDriver.h>
+#include <proxygen/lib/http/session/test/MockSessionObserver.h>
 #include <proxygen/lib/http/session/test/TestUtils.h>
 #include <quic/api/test/MockQuicSocket.h>
 #include <wangle/acceptor/ConnectionManager.h>
@@ -188,6 +189,9 @@ class HQDownstreamSessionTest : public HQSessionTest {
       testing::StrictMock<proxygen::MockHTTPHandler>& handler,
       folly::Function<void()> fn = folly::Function<void()>());
 
+  std::unique_ptr<proxygen::MockSessionObserver> addMockSessionObserver(
+      proxygen::MockSessionObserver::EventSet eventSet);
+
   std::unordered_map<quic::StreamId, ClientStream> requests_;
   quic::StreamId nextStreamId_{0};
   quic::QuicSocket::StreamTransportInfo streamTransInfo_;
