@@ -9,6 +9,7 @@
 #include <proxygen/lib/services/Service.h>
 
 #include <proxygen/lib/services/RequestWorkerThread.h>
+#include <proxygen/lib/services/RequestWorkerThreadNoExecutor.h>
 #include <proxygen/lib/services/ServiceWorker.h>
 
 namespace proxygen {
@@ -25,6 +26,12 @@ void Service::addServiceWorker(std::unique_ptr<ServiceWorker> worker,
   workers_.emplace_back(std::move(worker));
 }
 
+void Service::addServiceWorker(std::unique_ptr<ServiceWorker> worker,
+                               RequestWorkerThreadNoExecutor* reqWorker) {
+  reqWorker->addServiceWorker(this, worker.get());
+  workers_.emplace_back(std::move(worker));
+}
+
 void Service::clearServiceWorkers() {
   workers_.clear();
 }
